@@ -5,8 +5,7 @@ from django.forms import ChoiceField
 from data.models.models import Calibration, Hardware, Accessory, Channel, HardwareConfig, \
     CalibrationConstants, DHT22, MCP3008, \
     ModProbe, PiPico, VEML7700, HardwareChannelTypes, Hub, Category, AccessoryType, SPIIo, SerialIo, PwmIo, I2cIo, \
-    DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo,PiPicoACAnalogIo, HardwareIO, PMSA0031
-
+    DeviceFileIo, MCPAnalogIo, PiGpio, PiPicoAnalogIo, PiPicoACAnalogIo, HardwareIO, PMSA0031
 
 
 class HubForm(forms.ModelForm):
@@ -135,6 +134,7 @@ class HardwareVEML7700Form(HardwareForm):
         model = VEML7700
         fields = ("__all__")
 
+
 class HardwarePMSA0031Form(HardwareForm):
     def __init__(self, *args, **kwargs):
         super(HardwarePMSA0031Form, self).__init__(*args, **kwargs)
@@ -143,6 +143,7 @@ class HardwarePMSA0031Form(HardwareForm):
         model = PMSA0031
         fields = ("__all__")
 
+
 class AccessoryForm(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
@@ -231,10 +232,12 @@ class HardwareIoForm(forms.ModelForm):
         #     self.fields[name].widget.attrs.update({
         #         'class': 'form-control',
         #     })
+
     class Meta:
         model = HardwareIO
         fields = ("__all__")
 
+
 class SPIIoForm(HardwareIoForm):
 
     def __init__(self, *args, **kwargs):
@@ -373,6 +376,7 @@ class PiPicoAnalogIoForm(HardwareIoForm):
         model = PiPicoAnalogIo
         fields = ("__all__")
 
+
 class PiPicoACAnalogIoForm(HardwareIoForm):
 
     def __init__(self, *args, **kwargs):
@@ -392,6 +396,7 @@ class PiPicoACAnalogIoForm(HardwareIoForm):
         model = PiPicoACAnalogIo
         fields = ("__all__")
 
+
 class PiGpioForm(HardwareIoForm):
 
     def __init__(self, *args, **kwargs):
@@ -419,7 +424,7 @@ PiPico = 'PiPico'
 VEML7700 = 'VEML7700'
 PMSA0031 = 'PMSA0031'
 CHOICES = (('DHT22', 'DHT22'), ('MCP3008', 'MCP3008'), ('ModProbe', 'ModProbe'), ('PiPico', 'PiPico'),
-           ('VEML7700', 'VEML7700'),('PMSA0031','PMSA0031'))
+           ('VEML7700', 'VEML7700'), ('PMSA0031', 'PMSA0031'))
 
 
 class HardwareTypeForm(forms.Form):
@@ -441,7 +446,7 @@ PiGPIO = 'Pi GPIO'
 
 hardware_io_choices = (
     (SPI, SPI), (Serial, Serial), (PWM, PWM), (I2C, I2C), (DeviceFile, DeviceFile), (MCPChannel, MCPChannel),
-    (PiPicoAnalog, PiPicoAnalog),(PiPicoACAnalog, PiPicoACAnalog), (PiGPIO, PiGPIO))
+    (PiPicoAnalog, PiPicoAnalog), (PiPicoACAnalog, PiPicoACAnalog), (PiGPIO, PiGPIO))
 
 
 class HardwareIOTypeForm(forms.Form):
@@ -454,55 +459,54 @@ class HardwareIOTypeForm(forms.Form):
     child_hardware.widget = forms.HiddenInput()
     child_channel.widget = forms.HiddenInput()
     hub.widget = forms.HiddenInput()
+
     # def __init__(self, *args, **kwargs):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
         super(HardwareIOTypeForm, self).__init__(*args, **kwargs)
 
-
     class Meta:
-        fields = ['type','parent_hardware','child_hardware','child_channel','hub']
+        fields = ['type', 'parent_hardware', 'child_hardware', 'child_channel', 'hub']
 
 
+from django.forms.models import inlineformset_factory, BaseForm
+from data.models.models import HardwareStats, DataTransformer, DataTransformerConstants, HardwareDataTransformer, \
+    HardwareStatsDataTransformer
 
-from django.forms.models import inlineformset_factory,BaseForm
-from data.models.models import HardwareStats,DataTransformer,DataTransformerConstants,HardwareDataTransformer,HardwareStatsDataTransformer
-
-DataTransformerInlineFormset = inlineformset_factory(DataTransformer, fk_name='data_transformer_child', extra=1)
+DataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer, fk_name='data_transformer_child',
+                                                     extra=1)
 DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1)
 HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1)
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1)
 
+
 class DataTransformerForm(BaseForm):
 
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
         form.nested_data_transformer_form = DataTransformerInlineFormset(
-                        instance=form.instance,
-                        data=form.data if form.is_bound else None,
-                        files=form.files if form.is_bound else None,
-                        extra=1)
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None,
+            extra=1)
 
         form.nested_constants_form = DataConstantsTransformerInlineFormset(
-                        instance=form.instance,
-                        data=form.data if form.is_bound else None,
-                        files=form.files if form.is_bound else None,
-                        extra=1)
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None,
+            extra=1)
 
         form.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-                        instance=form.instance,
-                        data=form.data if form.is_bound else None,
-                        files=form.files if form.is_bound else None,
-                        extra=1)
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None,
+            extra=1)
 
         form.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-                        instance=form.instance,
-                        data=form.data if form.is_bound else None,
-                        files=form.files if form.is_bound else None,
-                        extra=1)
-
-
+            instance=form.instance,
+            data=form.data if form.is_bound else None,
+            files=form.files if form.is_bound else None,
+            extra=1)
 
 # DataTransformerFormset = form_factory(DataTransformer,formset=DataTransformerForm)
-
